# frozen_string_literal: true

module Family
  class CelebrityFamily < ::Family::Family
  end
end
